Qubit Executor
Core executor abstractions, task handles, and basic executor implementations.
Modules
- executor
- Execution strategy abstractions and basic executor implementations.
- service
- Managed executor service abstractions and basic service implementations.
Structs
- Task
Completion - Completion endpoint owned by a task runner.
- Task
Completion Pair - One-shot pair of endpoints for an accepted task.
- Task
Handle - Handle for a task running outside the caller’s current stack.
- Task
Runner - Runner that executes a callable task with standard task-handle semantics.
Enums
- Task
Execution Error - Error observed when retrieving the result of an accepted task.
Type Aliases
- Task
Result - Result type used by managed task handles.