Module executor

Module executor 

Execution strategy abstractions and basic executor implementations.

Structs

DelayExecutor
Executor that starts each task after a fixed delay.
DirectExecutor
Executes tasks immediately on the caller thread.
ThreadPerTaskExecutor
Executes each task on a dedicated OS thread.

Traits

Executor
Executes fallible one-time tasks according to an implementation-defined strategy.
FutureExecutor
Marker trait for executors whose execution carrier is a future.