ScheduleExecutor

Struct ScheduleExecutor 

pub struct ScheduleExecutor { /* private fields */ }
Executor that starts each task at a specified monotonic instant.

ScheduleExecutor creates the returned TrackedTask immediately, starts a helper OS thread, waits on that helper thread until the configured Instant, and then runs the task on the helper thread. If the configured instant is not in the future, the helper thread runs the task immediately.

Implementations

Source

impl ScheduleExecutor

pub fn at(instant: Instant) -> Self

Creates an executor that starts tasks at the supplied monotonic instant.

Parameters
  • instant - Monotonic instant at which each submitted task starts.
Returns

A schedule executor using instant.

pub fn with_hook(self, hook: Arc<dyn TaskHook>) -> Self

Returns a copy of this executor using the supplied task hook.

Parameters
  • hook - Hook notified about accepted task lifecycle events.
Returns

This executor configured with hook.

pub fn with_stack_size(self, stack_size: usize) -> Self

Returns a copy of this executor using the supplied helper thread stack size.

Parameters
  • stack_size - Stack size in bytes for each helper thread.
Returns

This executor configured with stack_size.

pub const fn instant(&self) -> Instant

Returns the configured scheduled instant.

Returns

The monotonic instant at which each task starts.