Module service

Module service 

Managed executor service abstractions and basic service implementations.

Structs

StopReport
Summary returned by an immediate executor-service stop request.
ThreadPerTaskExecutorService
Managed service that runs every accepted task on a dedicated OS thread.
ThreadPerTaskExecutorServiceBuilder
Builder for ThreadPerTaskExecutorService.

Enums

ExecutorServiceBuilderError
Error returned when an executor service cannot be built.
ExecutorServiceLifecycle
Lifecycle state for a managed executor service.
SubmissionError
Error returned when an executor service refuses to accept a task.

Traits

ExecutorService
Managed task service with submission and lifecycle control.