Module task

Module task 

Task handles and task-result types.

Modules

spi
Service-provider interfaces for custom executor implementations.

Structs

TaskHandle
Lightweight result handle for a submitted callable task.
TaskHandleFuture
Future returned when awaiting a task handle by value.
TrackedTask
Result handle with active status tracking and pre-start cancellation.

Enums

CancelResult
Result of an attempt to cancel a tracked task.
TaskExecutionError
Error observed when retrieving the result of an accepted task.
TaskStatus
Observable lifecycle status for a submitted task.
TryGet
Result of a non-blocking attempt to retrieve a task result.

Type Aliases

TaskResult
Result type used by managed task handles.