Crate qubit_executor

Crate qubit_executor 

Qubit Executor

Core executor abstractions, task handles, and basic executor implementations.

Modules

executor
Execution strategy abstractions and basic executor implementations.
service
Managed executor service abstractions and basic service implementations.

Structs

TaskCompletion
Completion endpoint owned by a task runner.
TaskCompletionPair
One-shot pair of endpoints for an accepted task.
TaskHandle
Handle for a task running outside the caller’s current stack.
TaskRunner
Runner that executes a callable task with standard task-handle semantics.

Enums

TaskExecutionError
Error observed when retrieving the result of an accepted task.

Type Aliases

TaskResult
Result type used by managed task handles.