Module executor

Module executor 

Execution strategy abstractions and basic executor implementations.

Structs

DelayExecutor
Executor that starts each task after a fixed delay.
DirectExecutor
Executes tasks immediately on the caller thread.
ScheduleExecutor
Executor that starts each task at a specified monotonic instant.
ThreadPerTaskExecutor
Executes each task on a dedicated OS thread.
ThreadPerTaskExecutorBuilder
Builder for ThreadPerTaskExecutor.

Traits

Executor
Executes fallible one-time tasks according to an implementation-defined strategy.