pub struct DirectExecutor { /* private fields */ }Expand description
Executes tasks immediately on the caller thread.
This executor is useful for deterministic tests and simple composition where task execution should happen in the same call stack.
Implementations
Sourceimpl DirectExecutor
impl DirectExecutor