DirectExecutor

Struct DirectExecutor 

pub struct DirectExecutor;
Executes tasks immediately on the caller thread.

This executor is useful for deterministic tests and simple composition where task execution should happen in the same call stack.