pub struct ScheduleExecutor { /* private fields */ }Expand description
Executor that starts each task at a specified monotonic instant.
ScheduleExecutor creates the returned TrackedTask immediately, starts
a helper OS thread, waits on that helper thread until the configured
Instant, and then runs the task on the helper thread. If the configured
instant is not in the future, the helper thread runs the task immediately.
Implementations