Module service

Module service 

Managed executor service abstractions and basic service implementations.

Structs

ShutdownReport
Summary returned by an immediate executor-service shutdown request.
ThreadPerTaskExecutorService
Managed service that runs every accepted task on a dedicated OS thread.

Enums

RejectedExecution
Error returned when an executor service refuses to accept a task.

Traits

ExecutorService
Managed task service with submission and lifecycle control.