pub enum ExecutorServiceBuilderError {
ZeroPoolSize,
ZeroMaximumPoolSize,
CorePoolSizeExceedsMaximum {
core_pool_size: usize,
maximum_pool_size: usize,
},
ZeroQueueCapacity,
ZeroStackSize,
ZeroKeepAlive,
SpawnWorker {
index: Option<usize>,
source: Error,
},
}Expand description
Error returned when an executor service cannot be built.
This error is shared by executor-service implementations whose construction may validate worker, queue, timeout, stack, or thread-spawn configuration.
Variants
ZeroPoolSize
The configured fixed worker count is zero.
ZeroMaximumPoolSize
The configured maximum pool size is zero.
CorePoolSizeExceedsMaximum
The configured core pool size is greater than the maximum pool size.
Fields
ZeroQueueCapacity
The configured bounded queue capacity is zero.
ZeroStackSize
The configured worker stack size is zero.
ZeroKeepAlive
The configured keep-alive timeout is zero.
SpawnWorker
A worker thread could not be spawned.
Implementations
Sourceimpl ExecutorServiceBuilderError
impl ExecutorServiceBuilderError
Sourcepub fn from_submission_error(error: SubmissionError) -> Self
pub fn from_submission_error(error: SubmissionError) -> Self