Task handles and task-result types.
Modules
- spi
- Service-provider interfaces for custom executor implementations.
Structs
- Task
Handle - Lightweight result handle for a submitted callable task.
- Task
Handle Future - Future returned when awaiting a task handle by value.
- Tracked
Task - Result handle with active status tracking and pre-start cancellation.
Enums
- Cancel
Result - Result of an attempt to cancel a tracked task.
- Task
Execution Error - Error observed when retrieving the result of an accepted task.
- Task
Status - Observable lifecycle status for a submitted task.
- TryGet
- Result of a non-blocking attempt to retrieve a task result.
Type Aliases
- Task
Result - Result type used by managed task handles.