pub enum CancelResult {
Cancelled,
AlreadyRunning,
AlreadyFinished,
Unsupported,
}Expand description
Result of an attempt to cancel a tracked task.
Variants
Cancelled
The task was cancelled before it started.
AlreadyRunning
The task had already started and cannot be cancelled cooperatively.
AlreadyFinished
The task had already reached a terminal state.
Unsupported
The backing service or handle does not support active cancellation.